pub struct LocationMethods<'a, C>where
C: 'a,{ /* private fields */ }Expand description
A builder providing access to all methods supported on location resources.
It is not used directly, but through the MyBusinessVerifications hub.
Example
Instantiate a resource builder
extern crate hyper;
extern crate hyper_rustls;
extern crate google_mybusinessverifications1 as mybusinessverifications1;
use mybusinessverifications1::{MyBusinessVerifications, FieldMask, hyper_rustls, hyper_util, yup_oauth2};
let secret: yup_oauth2::ApplicationSecret = Default::default();
let connector = hyper_rustls::HttpsConnectorBuilder::new()
.with_native_roots()
.unwrap()
.https_only()
.enable_http2()
.build();
let executor = hyper_util::rt::TokioExecutor::new();
let auth = yup_oauth2::InstalledFlowAuthenticator::with_client(
secret,
yup_oauth2::InstalledFlowReturnMethod::HTTPRedirect,
yup_oauth2::client::CustomHyperClientBuilder::from(
hyper_util::client::legacy::Client::builder(executor).build(connector),
),
).build().await.unwrap();
let client = hyper_util::client::legacy::Client::builder(
hyper_util::rt::TokioExecutor::new()
)
.build(
hyper_rustls::HttpsConnectorBuilder::new()
.with_native_roots()
.unwrap()
.https_or_http()
.enable_http2()
.build()
);
let mut hub = MyBusinessVerifications::new(client, auth);
// Usually you wouldn't bind this to a variable, but keep calling *CallBuilders*
// like `fetch_verification_options(...)`, `get_voice_of_merchant_state(...)`, `verifications_complete(...)`, `verifications_list(...)` and `verify(...)`
// to build up your call.
let rb = hub.locations();Implementations
Sourceimpl<'a, C> LocationMethods<'a, C>
impl<'a, C> LocationMethods<'a, C>
Sourcepub fn verifications_complete(
&self,
request: CompleteVerificationRequest,
name: &str,
) -> LocationVerificationCompleteCall<'a, C>
pub fn verifications_complete( &self, request: CompleteVerificationRequest, name: &str, ) -> LocationVerificationCompleteCall<'a, C>
Create a builder to help you perform the following task:
Completes a PENDING verification. It is only necessary for non AUTO verification methods. AUTO verification request is instantly VERIFIED upon creation.
Arguments
request- No description provided.name- Required. Resource name of the verification to complete.
Sourcepub fn verifications_list(
&self,
parent: &str,
) -> LocationVerificationListCall<'a, C>
pub fn verifications_list( &self, parent: &str, ) -> LocationVerificationListCall<'a, C>
Create a builder to help you perform the following task:
List verifications of a location, ordered by create time.
Arguments
parent- Required. Resource name of the location that verification requests belong to.
Sourcepub fn fetch_verification_options(
&self,
request: FetchVerificationOptionsRequest,
location: &str,
) -> LocationFetchVerificationOptionCall<'a, C>
pub fn fetch_verification_options( &self, request: FetchVerificationOptionsRequest, location: &str, ) -> LocationFetchVerificationOptionCall<'a, C>
Create a builder to help you perform the following task:
Reports all eligible verification options for a location in a specific language.
Arguments
request- No description provided.location- Required. The location to verify.
Sourcepub fn get_voice_of_merchant_state(
&self,
name: &str,
) -> LocationGetVoiceOfMerchantStateCall<'a, C>
pub fn get_voice_of_merchant_state( &self, name: &str, ) -> LocationGetVoiceOfMerchantStateCall<'a, C>
Create a builder to help you perform the following task:
Gets the VoiceOfMerchant state.
Arguments
name- Required. Resource name of the location.
Sourcepub fn verify(
&self,
request: VerifyLocationRequest,
name: &str,
) -> LocationVerifyCall<'a, C>
pub fn verify( &self, request: VerifyLocationRequest, name: &str, ) -> LocationVerifyCall<'a, C>
Create a builder to help you perform the following task:
Starts the verification process for a location.
Arguments
request- No description provided.name- Required. Resource name of the location to verify.